@@ -627,6 +627,24 @@ parse_geometry (const char   *string,
                 unsigned int *width,
                 unsigned int *height)
 {
+  int _x, _y;
+  unsigned int _width, _height;
+  if (x == NULL)
+    x = &_x;
+  else
+    *x = 0;
+  if (y == NULL)
+    y = &_y;
+  else
+    *y = 0;
+  if (width == NULL)
+    width = &_width;
+  else
+    *width = 0;
+  if (height == NULL)
+    height = &_height;
+  else
+    *height = 0;
 #ifdef ENABLE_X11
   if (WINDOWING_IS_X11 ())
     return XParseGeometry (string, x, y, width, height);
@@ -884,7 +902,8 @@ move_window_to_saved_workspace (GtkWidget *window,
                                         user_data);
 
 #ifdef ENABLE_X11
-  if (WINDOWING_IS_X11 ())
+  gdk_display = gtk_widget_get_display (GTK_WIDGET (window));
+  if (GDK_IS_X11_DISPLAY (gdk_display))
     {
       // EWMH says that we can set _NET_WM_DESKTOP on our own window before
       // mapping it, and the WM should honor our request.  However, xfwm4
@@ -893,7 +912,6 @@ move_window_to_saved_workspace (GtkWidget *window,
       // Firefox does) is to wait until the window is mapped, and then send a
       // ClientMessage to the root window to ask the WM to move us.
 
-      gdk_display = gtk_widget_get_display (GTK_WIDGET (window));
       gdk_screen = gtk_widget_get_screen (GTK_WIDGET (window));
 
       gdk_x11_display_error_trap_push (gdk_display);
@@ -1029,8 +1047,11 @@ terminal_app_open_window (TerminalApp        *app,
                                            attr->borders,
                                            attr->toolbar);
 
+      gboolean maximize_default;
+      g_object_get (G_OBJECT (app->preferences), "misc-maximize-default", &maximize_default, NULL);
+
       /* apply normal window properties */
-      if (attr->maximize)
+      if (maximize_default || attr->maximize)
         gtk_window_maximize (GTK_WINDOW (window));
       if (attr->minimize)
         gtk_window_iconify (GTK_WINDOW (window));
