@@ -13,13 +13,12 @@
  * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
  * more details.
  *
- * You should have received a copy of the GNU General Public License along with
- * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
- * Place, Suite 330, Boston, MA  02111-1307  USA.
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __TERMINAL_DBUS_H__
-#define __TERMINAL_DBUS_H__
+#ifndef TERMINAL_GDBUS_H
+#define TERMINAL_GDBUS_H
 
 #include <terminal/terminal-app.h>
 
@@ -33,4 +32,4 @@ gboolean  terminal_gdbus_invoke_launch     (gint          argc,
 
 G_END_DECLS
 
-#endif /* !__TERMINAL_DBUS_H__ */
+#endif /* !TERMINAL_GDBUS_H */
