@@ -201,6 +201,7 @@ terminal_preferences_dialog_init (TerminalPreferencesDialog *dialog)
   GtkWidget     *combo;
   gchar         *current;
   gint           row = 0;
+  const gchar   *text;
 
   /* grab a reference on the preferences */
   dialog->preferences = terminal_preferences_get ();
@@ -508,7 +509,7 @@ terminal_preferences_dialog_init (TerminalPreferencesDialog *dialog)
   g_object_bind_property (G_OBJECT (dialog->preferences), "misc-show-unsafe-paste-dialog",
                           G_OBJECT (button), "active",
                           G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
-  gtk_widget_set_tooltip_text (button, _("Show a dialog that allows to edit text that is considered unsafe for pasting"));
+  gtk_widget_set_tooltip_text (button, _("Show a dialog that allows one to edit text that is considered unsafe for pasting"));
   gtk_grid_attach (GTK_GRID (grid), button, 1, row, 1, 1);
   gtk_widget_show (button);
 
@@ -795,8 +796,10 @@ terminal_preferences_dialog_init (TerminalPreferencesDialog *dialog)
   /* next row */
   row++;
 
-  label = gtk_label_new_with_mnemonic (_("Cursor blinks:"));
+  label = gtk_label_new_with_mnemonic (_("Text blinks:"));
+  text = _("Controls whether text in the terminal is allowed to blink when '\\e[5m' escape codes are used.");
   gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
+  gtk_widget_set_tooltip_text (label, text);
   gtk_grid_attach (GTK_GRID (grid), label, 0, row, 1, 1);
   gtk_widget_show (label);
 
@@ -809,6 +812,7 @@ terminal_preferences_dialog_init (TerminalPreferencesDialog *dialog)
                           G_OBJECT (combo), "active",
                           G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
   gtk_widget_set_hexpand (combo, TRUE);
+  gtk_widget_set_tooltip_text (combo, text);
   gtk_grid_attach (GTK_GRID (grid), combo, 1, row, 5, 1);
   terminal_gtk_label_set_a11y_relation (GTK_LABEL (label), combo);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), combo);
@@ -1034,12 +1038,26 @@ terminal_preferences_dialog_init (TerminalPreferencesDialog *dialog)
   /* Next row */
   row++;
 
+  button = gtk_check_button_new_with_mnemonic (_("_Maximize new windows"));
+  g_object_bind_property (G_OBJECT (dialog->preferences), "misc-maximize-default",
+                          G_OBJECT (button), "active",
+                          G_BINDING_BIDIRECTIONAL | G_BINDING_SYNC_CREATE);
+  gtk_widget_set_tooltip_text (button, _("Enable this option to maximize newly created terminal windows."));
+  gtk_grid_attach (GTK_GRID (grid), button, 0, row, 5, 1);
+  gtk_widget_show (button);
+
+  /* Next row */
+  row++;
+
   label = gtk_label_new_with_mnemonic (_("Default geometry"));
   gtk_label_set_xalign (GTK_LABEL (label), 0.0f);
   gtk_grid_attach (GTK_GRID (grid), label, 0, row, 1, 1);
   gtk_widget_show (label);
 
   button = gtk_spin_button_new_with_range (10, 4000, 1);
+  g_object_bind_property (G_OBJECT (dialog->preferences), "misc-maximize-default",
+                          G_OBJECT (button), "sensitive",
+                          G_BINDING_INVERT_BOOLEAN | G_BINDING_SYNC_CREATE);
   dialog->geometry_set_signal_id[GEOMETRY_COLUMN] =
     g_signal_connect_swapped (button, "value-changed",
                               G_CALLBACK (terminal_preferences_dialog_geometry_changed), dialog);
@@ -1055,6 +1073,9 @@ terminal_preferences_dialog_init (TerminalPreferencesDialog *dialog)
   gtk_widget_show (label);
 
   button = gtk_spin_button_new_with_range (10, 3000, 1);
+  g_object_bind_property (G_OBJECT (dialog->preferences), "misc-maximize-default",
+                          G_OBJECT (button), "sensitive",
+                          G_BINDING_INVERT_BOOLEAN | G_BINDING_SYNC_CREATE);
   dialog->geometry_set_signal_id[GEOMETRY_ROW] =
     g_signal_connect_swapped (button, "value-changed",
                               G_CALLBACK (terminal_preferences_dialog_geometry_changed), dialog);
@@ -2166,6 +2187,7 @@ terminal_gtk_label_set_a11y_relation (GtkLabel  *label,
   relation = atk_relation_new (&object, 1, ATK_RELATION_LABEL_FOR);
   atk_relation_set_add (relations, relation);
   g_object_unref (G_OBJECT (relation));
+  g_object_unref (relations);
 }
 
 
