@@ -92,6 +92,7 @@ enum
   PROP_MISC_BELL,
   PROP_MISC_BELL_URGENT,
   PROP_MISC_BORDERS_DEFAULT,
+  PROP_MISC_MAXIMIZE_DEFAULT,
   PROP_MISC_CURSOR_BLINKS,
   PROP_MISC_CURSOR_SHAPE,
   PROP_MISC_DEFAULT_GEOMETRY,
@@ -199,7 +200,7 @@ static void
 transform_string_to_color (const GValue *src,
                            GValue       *dst)
 {
-  GdkRGBA color;
+  GdkRGBA color = { 0 };
 
   gdk_rgba_parse (&color, g_value_get_string (src));
   g_value_set_boxed (dst, &color);
@@ -849,6 +850,16 @@ terminal_preferences_class_init (TerminalPreferencesClass *klass)
                             TRUE,
                             G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
 
+  /**
+   * TerminalPreferences:misc-maximize-default:
+   **/
+  preferences_props[PROP_MISC_MAXIMIZE_DEFAULT] =
+      g_param_spec_boolean ("misc-maximize-default",
+                            NULL,
+                            "MiscMaximizeDefault",
+                            FALSE,
+                            G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
+
   /**
    * TerminalPreferences:misc-cursor-blinks:
    **/
@@ -1281,7 +1292,7 @@ terminal_preferences_init (TerminalPreferences *preferences)
   preferences->channel = xfconf_channel_get ("xfce4-terminal");
 
   channels = xfconf_list_channels ();
-  if (!g_strv_contains ((const gchar * const *) channels, "xfce4-terminal"))
+  if (channels != NULL && !g_strv_contains ((const gchar * const *) channels, "xfce4-terminal"))
     {
       /* try to load the old config file & save changes */
       terminal_preferences_load_rc_file (preferences);
