@@ -41,6 +41,7 @@ typedef enum
     TERMINAL_WINDOW_ACTION_FILE_MENU,
     TERMINAL_WINDOW_ACTION_NEW_TAB,
     TERMINAL_WINDOW_ACTION_NEW_WINDOW,
+    TERMINAL_WINDOW_ACTION_OPEN_FOLDER,
     TERMINAL_WINDOW_ACTION_UNDO_CLOSE_TAB,
     TERMINAL_WINDOW_ACTION_DETACH_TAB,
     TERMINAL_WINDOW_ACTION_CLOSE_TAB,
@@ -56,9 +57,6 @@ typedef enum
     TERMINAL_WINDOW_ACTION_SELECT_ALL,
     TERMINAL_WINDOW_ACTION_COPY_INPUT,
     TERMINAL_WINDOW_ACTION_PREFERENCES,
-#if LIBXFCE4UI_CHECK_VERSION (4, 17, 2)
-    TERMINAL_WINDOW_ACTION_SHORTCUTS,
-#endif
     TERMINAL_WINDOW_ACTION_VIEW_MENU,
     TERMINAL_WINDOW_ACTION_ZOOM_IN,
     TERMINAL_WINDOW_ACTION_ZOOM_IN_ALT,
@@ -85,6 +83,7 @@ typedef enum
     TERMINAL_WINDOW_ACTION_CONTENTS,
     TERMINAL_WINDOW_ACTION_ABOUT,
     TERMINAL_WINDOW_ACTION_ZOOM_MENU,
+    TERMINAL_WINDOW_ACTION_TOGGLE_MENUBAR,
     TERMINAL_WINDOW_ACTION_SHOW_MENUBAR,
     TERMINAL_WINDOW_ACTION_SHOW_TOOLBAR,
     TERMINAL_WINDOW_ACTION_SHOW_BORDERS,
@@ -189,16 +188,13 @@ gint               terminal_window_get_menubar_height       (TerminalWindow
 
 gint               terminal_window_get_toolbar_height       (TerminalWindow     *window);
 
-void               terminal_window_action_show_menubar      (TerminalWindow     *window);
-
-void               terminal_window_update_tab_key_accels    (TerminalWindow     *window,
-                                                             GSList             *tab_key_accels);
-
 void               terminal_window_update_goto_accels       (TerminalWindow     *window);
 
 XfceGtkActionEntry *terminal_window_get_action_entry         (TerminalWindow      *window,
                                                               TerminalWindowAction action);
 
+XfceGtkActionEntry *terminal_window_get_action_entries      (void);
+
 G_END_DECLS
 
 #endif /* !TERMINAL_WINDOW_H */
